Documentation
¶
Index ¶
- type AnnotationFunc
- type DocumentFunc
- type DocumentTypeFunc
- type EdgeTypeFunc
- type ExternalReferenceFunc
- type Func
- type HashesEntryFunc
- type IdentifiersEntryFunc
- type MetadataFunc
- type NodeFunc
- type NodeListFunc
- type PersonFunc
- type PropertyFunc
- type PurposeFunc
- type Query
- type SourceDataFunc
- type ToolFunc
- type TraverseAnnotation
- type TraverseDocument
- type TraverseDocumentType
- type TraverseEdgeType
- type TraverseExternalReference
- type TraverseFunc
- type TraverseHashesEntry
- type TraverseIdentifiersEntry
- type TraverseMetadata
- type TraverseNode
- type TraverseNodeList
- type TraversePerson
- type TraverseProperty
- type TraversePurpose
- type TraverseSourceData
- type TraverseTool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnnotationFunc ¶
The AnnotationFunc type is an adapter to allow the use of ordinary function as a Querier.
type DocumentFunc ¶
The DocumentFunc type is an adapter to allow the use of ordinary function as a Querier.
type DocumentTypeFunc ¶
The DocumentTypeFunc type is an adapter to allow the use of ordinary function as a Querier.
type EdgeTypeFunc ¶
The EdgeTypeFunc type is an adapter to allow the use of ordinary function as a Querier.
type ExternalReferenceFunc ¶
The ExternalReferenceFunc type is an adapter to allow the use of ordinary function as a Querier.
type Func ¶
The Func type is an adapter that allows ordinary functions to be used as interceptors. Unlike traversal functions, interceptors are skipped during graph traversals. Note that the implementation of Func is different from the one defined in entgo.io/ent.InterceptFunc.
type HashesEntryFunc ¶
The HashesEntryFunc type is an adapter to allow the use of ordinary function as a Querier.
type IdentifiersEntryFunc ¶
The IdentifiersEntryFunc type is an adapter to allow the use of ordinary function as a Querier.
type MetadataFunc ¶
The MetadataFunc type is an adapter to allow the use of ordinary function as a Querier.
type NodeListFunc ¶
The NodeListFunc type is an adapter to allow the use of ordinary function as a Querier.
type PersonFunc ¶
The PersonFunc type is an adapter to allow the use of ordinary function as a Querier.
type PropertyFunc ¶
The PropertyFunc type is an adapter to allow the use of ordinary function as a Querier.
type PurposeFunc ¶
The PurposeFunc type is an adapter to allow the use of ordinary function as a Querier.
type Query ¶
type Query interface {
// Type returns the string representation of the query type.
Type() string
// Limit the number of records to be returned by this query.
Limit(int)
// Offset to start from.
Offset(int)
// Unique configures the query builder to filter duplicate records.
Unique(bool)
// Order specifies how the records should be ordered.
Order(...func(*sql.Selector))
// WhereP appends storage-level predicates to the query builder. Using this method, users
// can use type-assertion to append predicates that do not depend on any generated package.
WhereP(...func(*sql.Selector))
}
The Query interface represents an operation that queries a graph. By using this interface, users can write generic code that manipulates query builders of different types.
type SourceDataFunc ¶
The SourceDataFunc type is an adapter to allow the use of ordinary function as a Querier.
type TraverseAnnotation ¶
type TraverseAnnotation func(context.Context, *ent.AnnotationQuery) error
The TraverseAnnotation type is an adapter to allow the use of ordinary function as Traverser.
type TraverseDocument ¶
type TraverseDocument func(context.Context, *ent.DocumentQuery) error
The TraverseDocument type is an adapter to allow the use of ordinary function as Traverser.
type TraverseDocumentType ¶
type TraverseDocumentType func(context.Context, *ent.DocumentTypeQuery) error
The TraverseDocumentType type is an adapter to allow the use of ordinary function as Traverser.
type TraverseEdgeType ¶
type TraverseEdgeType func(context.Context, *ent.EdgeTypeQuery) error
The TraverseEdgeType type is an adapter to allow the use of ordinary function as Traverser.
type TraverseExternalReference ¶
type TraverseExternalReference func(context.Context, *ent.ExternalReferenceQuery) error
The TraverseExternalReference type is an adapter to allow the use of ordinary function as Traverser.
type TraverseFunc ¶
The TraverseFunc type is an adapter to allow the use of ordinary function as Traverser. If f is a function with the appropriate signature, TraverseFunc(f) is a Traverser that calls f.
type TraverseHashesEntry ¶
type TraverseHashesEntry func(context.Context, *ent.HashesEntryQuery) error
The TraverseHashesEntry type is an adapter to allow the use of ordinary function as Traverser.
type TraverseIdentifiersEntry ¶
type TraverseIdentifiersEntry func(context.Context, *ent.IdentifiersEntryQuery) error
The TraverseIdentifiersEntry type is an adapter to allow the use of ordinary function as Traverser.
type TraverseMetadata ¶
type TraverseMetadata func(context.Context, *ent.MetadataQuery) error
The TraverseMetadata type is an adapter to allow the use of ordinary function as Traverser.
type TraverseNode ¶
The TraverseNode type is an adapter to allow the use of ordinary function as Traverser.
type TraverseNodeList ¶
type TraverseNodeList func(context.Context, *ent.NodeListQuery) error
The TraverseNodeList type is an adapter to allow the use of ordinary function as Traverser.
type TraversePerson ¶
type TraversePerson func(context.Context, *ent.PersonQuery) error
The TraversePerson type is an adapter to allow the use of ordinary function as Traverser.
type TraverseProperty ¶
type TraverseProperty func(context.Context, *ent.PropertyQuery) error
The TraverseProperty type is an adapter to allow the use of ordinary function as Traverser.
type TraversePurpose ¶
type TraversePurpose func(context.Context, *ent.PurposeQuery) error
The TraversePurpose type is an adapter to allow the use of ordinary function as Traverser.
type TraverseSourceData ¶
type TraverseSourceData func(context.Context, *ent.SourceDataQuery) error
The TraverseSourceData type is an adapter to allow the use of ordinary function as Traverser.
type TraverseTool ¶
The TraverseTool type is an adapter to allow the use of ordinary function as Traverser.